Crate bytes_lit

Crate bytes_lit 

Bytes converts literals into an array of bytes.

Currently supports only integer literals of unbounded size.

The macros are intended for small byte inputs. There is no arbitrary limit, but very large inputs may result in long compilation times. For large amounts of bytes, store the bytes in a file and use include_bytes! instead.

Macros

bytes
Bytes converts literals into an array of bytes.
bytesmin
Bytesmin converts literals into an array of bytes of minimal size to capture the value.